@@ -96,18 +96,18 @@ option	--dark-green \
 
 option	--dark-cmy \
 	--dark-screen			\
-	--cm OCOMMAND=K/122		\
-	--cm    OFILE=K/122;D		\
-	--cm NCOMMAND=K/313		\
-	--cm    NFILE=K/313;D		\
-	--cm MCOMMAND=K/332		\
-	--cm    MFILE=K/332;D		\
+	--cm OCOMMAND=000/122		\
+	--cm    OFILE=000/122;D		\
+	--cm NCOMMAND=000/313		\
+	--cm    NFILE=000/313;D		\
+	--cm MCOMMAND=000/332		\
+	--cm    MFILE=000/332;D		\
 	--cm    ?LINE=220		\
 	--cdifopts='--dark-cmy'
 
 option	--dark-mono \
 	--dark-screen			\
-	--cm ?COMMAND=/{DARK_BG1}	\
+	--cm ?COMMAND=555/{DARK_BG1}	\
 	--cm    ?FILE=D/{DARK_BG1}	\
 	--cm    ?LINE=111		\
 	--cdifopts='--dark-mono'
